Package: aurora
Title: Build Stateless Web Apps with 'plumber2'
Version: 0.1.12
Authors@R: c(
    person("Andre", "Leite", email = "leite@castlab.org", role = c("aut", "cre")),
    person("Marcos", "Wasilew", email = "marcos.wasilew@gmail.com", role = "aut"),
    person("Hugo", "Vasconcelos", email = "hugo.vasconcelos@ufpe.br", role = "aut"),
    person("Carlos", "Amorin", email = "carlos.agaf@ufpe.br", role = "aut"),
    person("Diogo", "Bezerra", email = "diogo.bezerra@ufpe.br", role = "aut"),
    person("Júlia", "Nascimento Barreto", email = "juliabarreto@gd.seplag.pe.gov.br", role = "aut"))
Description: A scaffolding and deployment toolkit for building stateless web
    applications in R on top of the 'plumber2' web framework
    (<https://plumber2.posit.co/>). The UI is authored with 'bslib'
    and compiled to a static HTML asset at build time, while 'plumber2' serves
    the assets and exposes JSON API routes. Provides functions to scaffold app
    skeletons, run them locally, and generate Dockerfiles and images suitable
    for 'ShinyProxy' or plain Docker.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 4.1)
Imports: cli, fs, glue, htmltools, jsonlite, plumber2 (>= 0.2.0),
        rlang, yaml
Suggests: brand.yml, bslib (>= 0.9.0), callr, config, fiery, geojsonsf,
        httpuv, httr2, jose, knitr, later, nanoparquet, pak, reqres,
        rmarkdown, sf, shiny, sodium, testthat (>= 3.0.0), withr
VignetteBuilder: knitr
Config/testthat/edition: 3
URL: https://github.com/aurora-govpe/aurora-rpkg,
        https://aurora-govpe.github.io/aurora-rpkg/
BugReports: https://github.com/aurora-govpe/aurora-rpkg/issues
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-19 18:24:46 UTC; leite
Author: Andre Leite [aut, cre],
  Marcos Wasilew [aut],
  Hugo Vasconcelos [aut],
  Carlos Amorin [aut],
  Diogo Bezerra [aut],
  Júlia Nascimento Barreto [aut]
Maintainer: Andre Leite <leite@castlab.org>
Repository: CRAN
Date/Publication: 2026-06-24 09:10:09 UTC
Built: R 4.6.1; ; 2026-06-24 13:10:36 UTC; unix
