Aurora Template - [Demo](http://dominikserafin.github.io/aurora-template)
===============

### A free HTML5 template for personal and commercial usage.

It was created for my [personal portfolio](http://serafin.io/?utm_source=Aurora-Template&utm_medium=GitHub-Readme&utm_campaign=Freebie) (but I've never used it) and now I'm releasing it for free. Edit and use this template as you want, except selling or crediting it as your own.


#### Share Template

- [Share on Facebook](https://www.facebook.com/sharer/sharer.php?u=http%3A%2F%2Fserafin.io%2Faurora-template%2F&t=Free%20Aurora%20Template)
- [Share on Twitter](https://twitter.com/intent/tweet?source=http%3A%2F%2Fserafin.io%2Faurora-template%2F&text=Free%20Aurora%20Template:%20http%3A%2F%2Fserafin.io%2Faurora-template%2F&via=SerafinDominik)
- [Share on Google+](https://plus.google.com/share?url=http%3A%2F%2Fserafin.io%2Faurora-template%2F)
- [Post to Tumblr](http://www.tumblr.com/share?v=3&u=http%3A%2F%2Fserafin.io%2Faurora-template%2F&t=Free%20Aurora%20Template&s=)
- [Pin It](http://pinterest.com/pin/create/button/?url=http%3A%2F%2Fserafin.io%2Faurora-template%2F&description=Beautiful%20free%20HTML5%20template%20created%20by%20Dominik%20Serafin.)



#### Follow Me

- [Follow me on Twitter](https://twitter.com/SerafinDominik)
- [Follow me on Dribbble](https://dribbble.com/DominikSerafin)
- [Follow me on Behance](https://www.behance.net/dominikserafin)



# Features

- Animated Background Gradient
- Cool Project Showcase
- Contact Form in PHP
- Responsive, Fast and Mobile Friendly
- Vector Icons and Font Awesome
- Sass and BEM Modular Stylesheet (with SourceMaps)



# FAQ & Usage

#### How can I change the e-mail address where contact form should send messages?

Just edit line 55 in /php/contact_form.php

```
    $to_email = "mail@example.com";
```

#### Contact form doesn't work :(

Make sure your server is able to execute PHP scripts and you've set a valid e-mail address.



#### How to edit stylesheets?

Although it isn't recommend you can directly edit /style/css/global.css or overwrite it with your styles.

If you know Sass and Gulp you shouldn't have a problem with editing provided stylesheets.



#### How to edit favicon?

Just use [Real Favicon Generator](http://realfavicongenerator.net/) and overwrite current favicon.


#### Why do you have a commit titled "initial files ass"?

It was meant to be "initial files add", but unfortunate typo is an unfortunate typo...


# Support

I'm busy most of the time so I can't provide extensive personal support. The code isn't that complicated, you probably shouldn't have any problems with it. If you do then please fill in issue and I'll try to help you at my free time.



# Contributing

If you've spotted a bug or you want to help in any way then please contribute by pull request or by filling an issue.

